@@ -5,11 +5,11 @@ from anypoint.models.statistics import DashboardStatistics, Statistic
 from anypoint.models.worker import Worker, WorkerStatistic
 
 if TYPE_CHECKING:
-    from anypoint import Anypoint
+    from anypoint.api.application import ApplicationApi
 
 
 class Application:
-    def __init__(self, raw_json, client: "Anypoint"):
+    def __init__(self, raw_json, client: "ApplicationApi"):
         self.domain: str = raw_json.get("domain")
         self.full_domain: str = raw_json.get("fullDomain")
         self.id: str = raw_json.get("id")
@@ -20,11 +20,15 @@ class Application:
         self.deployment_group_id: str = raw_json.get("deploymentGroupId")
 
         self.num_workers: int = raw_json.get("workers")
-        self.remaining_workers: int = raw_json.get("remainingWorkerCount")
+        self.remaining_workers: int = raw_json.get("remainingWorkerCount", 0)
         self.environment_id: str = raw_json.get("environment_id")
         self.statistics = None
         self.worker_statistics: List[WorkerStatistic] = []
         self.workers: List[Worker] = []
+        self.worker_type = raw_json.get("workerType")
+        self.worker_count = raw_json.get("workers", 0)
+        self.file_name = raw_json.get("filename")
+        self.href = raw_json.get("href")
 
         self._data = raw_json
         self._api_client = client
@@ -44,7 +48,10 @@ class Application:
         return self._api_client.get_application_statistics(self.environment_id, self.domain, date_from, date_to)
 
     def get_dashboard_statistics(self, date_from: datetime, date_to: datetime) -> DashboardStatistics:
-        return self._api_client.get_application_dashboard_statistics(self.environment_id,
-                                                                     self.domain,
-                                                                     date_from,
-                                                                     date_to)
+        return self._api_client.get_dashboard_statistics(self.environment_id,
+                                                         self.domain,
+                                                         date_from,
+                                                         date_to)
+
+    def get_insights(self):
+        return self._api_client.get_insights(self.environment_id, self.domain)
